package sun.security.provider;

import java.security.Permission;
import java.security.ProtectionDomain;
import java.security.PermissionCollection;
import java.security.CodeSource;
import java.net.MalformedURLException;
import java.security.URIParameter;
import java.security.Policy;
import java.security.PolicySpi;

public final class PolicySpiFile extends PolicySpi
{
    private PolicyFile pf;
    
    public PolicySpiFile(Policy.Parameters obj) {
        if (obj == null) {
            this.pf = new PolicyFile();
        }
        else {
            if (!(obj instanceof URIParameter)) {
                throw new IllegalArgumentException("Unrecognized policy parameter: " + obj);
            }
            URIParameter uriParameter = (URIParameter)obj;
            try {
                this.pf = new PolicyFile(uriParameter.getURI().toURL());
            }
            catch (MalformedURLException cause) {
                throw new IllegalArgumentException("Invalid URIParameter", cause);
            }
        }
    }
    
    @Override
    protected PermissionCollection engineGetPermissions(CodeSource codeSource) {
        return this.pf.getPermissions(codeSource);
    }
    
    @Override
    protected PermissionCollection engineGetPermissions(ProtectionDomain protectionDomain) {
        return this.pf.getPermissions(protectionDomain);
    }
    
    @Override
    protected boolean engineImplies(ProtectionDomain protectionDomain, Permission permission) {
        return this.pf.implies(protectionDomain, permission);
    }
    
    @Override
    protected void engineRefresh() {
        this.pf.refresh();
    }
}
